@@ -126,12 +126,33 @@ def _ensure_stderr_logs_are_active():
 
 def metamake_bin():
     """the actual metamake commandline tool (main function)"""
-
+    
     import sys
+    
+    # allow help from the commandline
+    if "--help" in sys.argv:
+        print >> sys.stderr, "latest metamake documentation can be found at http://pypi.python.org/pypi/metamake/"
+        raise SystemExit(0)
+
+    # the user didn't want help, they are actually trying to exec metamake
     import os
     sys.path.insert(0, os.getcwd())
     import metamake
-    import Makefile
+    
+    try:
+        import Makefile
+    except ImportError, e:
+        
+        errmsg = str(e)
+        if "Makefile" in errmsg:
+            # this was probably unable to find Makefile.py
+            print >> sys.stderr, "*** Makefile.py could not be loaded.  It appears that you have not defined one."
+        else:
+            # this was probably due to an import from within Makefile.py
+            print >> sys.stderr, "*** Makefile.py could not be loaded.  It appears that one of your imports is failing: '%s'." % errmsg
+        
+        # fail with nonzero error code
+        raise SystemExit(1)
     
     # any commandline argument without a '=' in it is a task that we want to run
     tasknames = [arg for arg in sys.argv[1:] if "=" not in arg]
