@@ -4,7 +4,7 @@ options(
     setup=Bunch(
         name="metamake",
         packages=['metamake'],
-        version="1.0.5",
+        version="1.0.6",
         license="BSD",
         author="Matt Pizzimenti",
         author_email="mjpizz+metamake@gmail.com",
@@ -126,7 +126,7 @@ under a single object called **path**::
         path("dist/include").makedirs()
         path("src/widget").copytree("dist/include/widget")
         for header_file in path("src/gadget").listdir("*.h"):
-            header_file.copyfile("dist/include/gadget/%%s" %% header_file.basename())
+            header_file.copyfile("dist/include/gadget/%s" % header_file.basename())
 
 Metamake extends Jason's library by providing console logging for file operations.
 This makes it easy to see the manipulations that are happening to your filesystem
