@@ -1,4 +1,6 @@
-from metamake import task
+from metamake import task, bootstrap
+
+bootstrap("Makefile.test")
 
 @task
 def testA():
